# Executing this R file recreates the figures, models and tests published by
# Franz Neuberger, Tobias Rüttenauer and Martin Bujard (2022) in
# Demographic Research:

# Where Does Public Childcare Boost Female Labor Force Participation?
# Exploring Geographical Heterogeneity across Germany 2007-2017

# and reproduces all analyses, graphics and most tables included in the manuscript and appendix

# R.version
# platform       aarch64-apple-darwin20
# arch           aarch64
# os             darwin20
# system         aarch64, darwin20
# status
# major          4
# minor          1.1
# year           2021
# month          08
# day            10
# svn rev        80725
# language       R
# version.string R version 4.1.1 (2021-08-10)
# nickname       Kick Things





rm(list = ls())
Sys.setlocale("LC_ALL", "en_US.UTF-8")


library(sp)
library(rgeos)
library(raster)
library(tmap)
library(tmaptools)
library(tidyverse)
library(plm)
library(texreg)
library(feisr)
library(parallel)
library(RColorBrewer)
library(viridisLite)



### feis extract function for texreg
extract.feis <-
  function (model,
            include.rsquared = TRUE,
            include.adjrs = TRUE,
            include.nobs = TRUE,
            ...)
  {
    s <- summary(model, ...)
    coefficient.names <- rownames(coef(s))
    coefficients <- coef(s)[, 1]
    standard.errors <- coef(s)[, 2]
    significance <- coef(s)[, 4]
    rs <- s$r.squared[1]
    adj <- s$r.squared[2]
    n <- length(model$residuals)
    gof <- numeric()
    gof.names <- character()
    gof.decimal <- logical()
    if (include.rsquared == TRUE) {
      gof <- c(gof, rs)
      gof.names <- c(gof.names, "R$^2$")
      gof.decimal <- c(gof.decimal, TRUE)
    }
    if (include.adjrs == TRUE) {
      gof <- c(gof, adj)
      gof.names <- c(gof.names, "Adj. R$^2$")
      gof.decimal <- c(gof.decimal, TRUE)
    }
    if (include.nobs == TRUE) {
      gof <- c(gof, n)
      gof.names <- c(gof.names, "Num. obs.")
      gof.decimal <- c(gof.decimal, FALSE)
    }
    tr <-
      createTexreg(
        coef.names = coefficient.names,
        coef = coefficients,
        se = standard.errors,
        pvalues = significance,
        gof.names = gof.names,
        gof = gof,
        gof.decimal = gof.decimal
      )
    return(tr)
  }


setMethod(
  "extract",
  signature = className("feis", "feisr"),
  definition = feisr:::extract.feis
)



### Reassign solve in base package with lower tolerance
solve.default.new <-
  function (a,
            b,
            tol = .Machine$double.eps ^ 3,
            LINPACK = FALSE,
            ...)
  {
    if (is.complex(a) || (!missing(b) && is.complex(b))) {
      a <- as.matrix(a)
      if (missing(b)) {
        b <- diag(1 + (0 + 0i), nrow(a))
        colnames(b) <- rownames(a)
      }
      return(.Internal(La_solve_cmplx(a, b)))
    }
    if (inherits(a, "qr")) {
      warning("solve.default called with a \"qr\" object: use 'qr.solve'")
      return(solve.qr(a, b, tol))
    }
    a <- as.matrix(a)
    if (missing(b)) {
      b <- diag(1, nrow(a))
      colnames(b) <- rownames(a)
    }
    .Internal(La_solve(a, b, tol))
  }

unlockBinding("solve", as.environment("package:base"))
assign("solve", solve.default.new, "package:base")

unlockBinding("solve", getNamespace("base"))
assign("solve", solve.default.new, getNamespace("base"))










###set wd
setwd(dirname(rstudioapi::getActiveDocumentContext()$path))
getwd()


load("Replicable_data.Rdata")
dim(inkar_long.df)

######################################
###Line Graphs Figure A1 to A3
######################################

##colors
gg_color_hue <- function(n) {
  hues = seq(15, 375, length = n + 1)
  hcl(h = hues, l = 65, c = 100)[1:n]
}
n = 4
cols = c("black", gg_color_hue(n))
cols

inkar_long.df$ost_fac <- as.factor(inkar_long.df$ost)
table(inkar_long.df$ost_fac)
levels(inkar_long.df$ost_fac) <- c("West", "East")
levels(inkar_long.df$ost_fac)
levels(inkar_long.df$kreistyp_fac)

inkar_long.df$kreistyp_fac <-
  ordered(inkar_long.df$kreistyp_fac,
          levels = c("Metro", "Urban", "Agglo", "Rural"))


temp <- inkar_long.df %>%
  dplyr::group_by(kreistyp_fac,  reportingyear) %>%
  dplyr::summarise(
    FLP  = mean(beschftigtenquotefrauen, na.rm = TRUE),
    childcare_02  = mean(betreuungvonkindermunter3jahre, na.rm =
                           TRUE),
    childcare_35  = mean(betreuungvonkinderm3bis5jahre, na.rm =
                           TRUE),
    fulltime_childcare_02  = mean(ganztags.betreuungsquotekleink, na.rm =
                                    TRUE),
    fulltime_childcare_35  = mean(ganztags.betreuungsquotevorsch)
  ) %>% as.data.frame()

head(temp)

temp2 <- inkar_long.df %>%
  dplyr::group_by(ost_fac,  reportingyear) %>%
  dplyr::summarise(
    FLP  = mean(beschftigtenquotefrauen, na.rm = TRUE),
    childcare_02  = mean(betreuungvonkindermunter3jahre, na.rm =
                           TRUE),
    childcare_35  = mean(betreuungvonkinderm3bis5jahre, na.rm =
                           TRUE),
    fulltime_childcare_02  = mean(ganztags.betreuungsquotekleink, na.rm =
                                    TRUE),
    fulltime_childcare_35  = mean(ganztags.betreuungsquotevorsch)
  ) %>% as.data.frame()
head(temp2)
colnames(temp2)[1] <- "kreistyp_fac"

temp3 <- inkar_long.df %>%
  dplyr::group_by(reportingyear) %>%
  dplyr::summarise(
    childcare_02  = mean(betreuungvonkindermunter3jahre, na.rm = TRUE),
    childcare_35  = mean(betreuungvonkinderm3bis5jahre, na.rm =
                           TRUE),
    FLP  = mean(beschftigtenquotefrauen, na.rm = TRUE),
    fulltime_childcare_02  = mean(ganztags.betreuungsquotekleink, na.rm =
                                    TRUE),
    fulltime_childcare_35  = mean(ganztags.betreuungsquotevorsch)
  ) %>% as.data.frame()
head(temp3)
temp3 <- cbind("Germany", temp3)
colnames(temp3)[1] <- "kreistyp_fac"

temp3 <- rbind(temp, temp2, temp3)
temp4 <-
  temp3 %>% gather(type, value,-c(reportingyear, kreistyp_fac))
temp4
temp4$kreistyp_fac <-
  ordered(temp4$kreistyp_fac, levels = rev(
    c("Germany", "East", "West", "", "Rural", "Agglo", "Urban", "Metro")
  ))


levels(temp4$kreistyp_fac)
temp4$kreistyp_fac <- fct_rev(temp4$kreistyp_fac)
temp4$type <- as.factor(temp4$type)

levels(temp4$type)
levels(temp4$type) <-
  c(
    "Childcare coverage 0-2",
    "Childcare coverage 3-5",
    "FLP",
    "Share of full-time slots 0-2",
    "Share of full-time slots 3-5"
  )

# Colors
cbPalette <-
  c(
    "black",
    inferno(
      2,
      begin = 0.5,
      end = 0.8,
      direction = -1
    ),
    "white",
    viridis(
      4,
      begin = 0.3,
      end = 0.9,
      direction = -1
    )
  )

scales::show_col(cbPalette)


##############################
##Descriptive Appendix Figures
##############################

# Figure A1
ggplot(data = filter(temp4, type == "FLP")) +
  geom_line(aes(
    x = reportingyear,
    y = value,
    color = kreistyp_fac,
    lty = kreistyp_fac
  ),
  lwd = 1.5) +
  facet_wrap( ~ type) +
  labs(col = "", lty = "") +
  xlab("Year") +
  ylab("Female Labor Force Participation in %") +
  theme_bw() +
  theme(
    legend.title = element_text(size = 20),
    legend.text = element_text(size = 20),
    legend.position = "bottom",
    panel.grid.minor.x = element_blank(),
    axis.title = element_text(size = 20),
    axis.text.y = element_text(
      size = 15,
      angle = 0,
      hjust = 0.5,
      color = "black"
    ),
    axis.text.x = element_text(
      size = 15,
      angle = 45,
      vjust = .5,
      color = "black"
    ),
    plot.title = element_text(size = 25, hjust = 0.5),
    legend.key.size = unit(3, "line"),
    strip.text.x = element_text(size = 20, face = "bold.italic")
  ) +
  scale_x_continuous(breaks = 2007:2017) +
  scale_color_manual(values = cbPalette, drop = FALSE) +
  scale_linetype_manual(values = c(1, 2, 2, 0, 3, 3, 3, 3), drop = FALSE) +
  guides(color = guide_legend(ncol = 4, byrow = TRUE))



# Figure A2
ggplot(data = filter(
  temp4,
  type == "Childcare coverage 0-2" |
    type == "Share of full-time slots 0-2"
)) +
  geom_line(aes(
    x = reportingyear,
    y = value,
    color = kreistyp_fac,
    lty = kreistyp_fac
  ),
  lwd = 1.5) +
  facet_wrap( ~ type) +
  labs(col = "", lty = "") +
  xlab("Year") +
  ylab("Female Labor Force Participation in %") +
  theme_bw() +
  theme(
    legend.title = element_text(size = 20),
    legend.text = element_text(size = 20),
    legend.position = "bottom",
    #  panel.grid.major.x = element_blank(),
    panel.grid.minor.x = element_blank(),
    axis.title = element_text(size = 20),
    axis.text.y = element_text(
      size = 15,
      angle = 0,
      hjust = 0.5,
      color = "black"
    ),
    axis.text.x = element_text(
      size = 15,
      angle = 45,
      vjust = .5,
      color = "black"
    ),
    plot.title = element_text(size = 25, hjust = 0.5),
    legend.key.size = unit(3, "line"),
    strip.text.x = element_text(size = 20, face = "bold.italic")
  ) +
  scale_x_continuous(breaks = 2007:2017) +
  scale_color_manual(values = cbPalette, drop = FALSE) +
  scale_linetype_manual(values = c(1, 2, 2, 0, 3, 3, 3, 3), drop = FALSE) +
  guides(color = guide_legend(ncol = 4, byrow = TRUE))

# Figure A3
ggplot(data = filter(
  temp4,
  type == "Childcare coverage 3-5" |
    type == "Share of full-time slots 3-5"
)) +
  geom_line(aes(
    x = reportingyear,
    y = value,
    color = kreistyp_fac,
    lty = kreistyp_fac
  ),
  lwd = 1.5) +
  facet_wrap( ~ type) +
  labs(col = "", lty = "") +
  xlab("Year") +
  ylab("Female Labor Force Participation in %") +
  theme_bw() +
  theme(
    legend.title = element_text(size = 20),
    legend.text = element_text(size = 20),
    legend.position = "bottom",
    #  panel.grid.major.x = element_blank(),
    panel.grid.minor.x = element_blank(),
    axis.title = element_text(size = 20),
    axis.text.y = element_text(
      size = 15,
      angle = 0,
      hjust = 0.5,
      color = "black"
    ),
    axis.text.x = element_text(
      size = 15,
      angle = 45,
      vjust = .5,
      color = "black"
    ),
    plot.title = element_text(size = 25, hjust = 0.5),
    legend.key.size = unit(3, "line"),
    strip.text.x = element_text(size = 20, face = "bold.italic")
  ) +
  scale_x_continuous(breaks = 2007:2017) +
  scale_color_manual(values = cbPalette, drop = FALSE) +
  scale_linetype_manual(values = c(1, 2, 2, 0, 3, 3, 3, 3), drop = FALSE) +
  guides(color = guide_legend(ncol = 4, byrow = TRUE))



##############
## Appendix Table A1
##############
##Compare increases
values_2007 <-  temp4[temp$reportingyear == "2007", ]
colnames(values_2007)[4] <- "value_2007"

values_2017 <-  temp4[temp$reportingyear == "2017", ]

temp_comp <- cbind(values_2007, values_2017[, 4])

colnames(temp_comp)[5] <- "value_2017"
temp_comp$diff <- temp_comp$value_2017 - temp_comp$value_2007
temp_comp$rate <- temp_comp$value_2017 / temp_comp$value_2007



levels(temp_comp$type)
temp_comp$type <- ordered(
  temp_comp$type,
  levels = c(
    "FLP",
    "Childcare coverage 0-2",
    "Share of full-time slots 0-2",
    "Childcare coverage 3-5",
    "Share of full-time slots 3-5"
  )
)

temp_comp <- temp_comp[order(temp_comp$type, temp_comp$kreistyp_fac), ]
temp_comp

tableX <- temp_comp[, -2]

colnames(tableX) <-
  c("Area",
    "Variable",
    "2007 (%)",
    "2017 (%)",
    "Change (abs.)",
    "Change rate")
levels(tableX$Variable)
levels(tableX$Variable) <-
  c("FLP" ,
    "Childc. cov. 0-2",
    "Share ft. slots 0-2",
    "Childc. cov. 3-5",
    "Share ft. slots 3-5")
rownames(tableX) <- NULL


tableX


#highest change rates?
temp_comp[order(temp_comp$rate), ]












##############
## Figure A4
##############
temp_comp_plot <-
  temp_comp %>% gather(point, value,-c(reportingyear, kreistyp_fac, type))
temp_comp_plot$point <- as.factor(temp_comp_plot$point)
levels(temp_comp_plot$point) <-
  c("Change in percentage points from 2007 to 2017",
    "Rate",
    "2007",
    "2017")


ggplot(temp_comp_plot[temp_comp_plot$point == "Change in percentage points from 2007 to 2017", ]) +
  geom_bar(position = "dodge",
           stat = "identity",
           aes(x = point, y = value, fill = kreistyp_fac)) +
  facet_wrap( ~ type) +
  scale_fill_manual(values = cbPalette, drop = FALSE) +
  labs(col = "", lty = "") +
  xlab("") +
  ylab("%") +
  theme_bw() +
  theme(
    legend.title = element_blank(),
    legend.text = element_text(size = 15),
    legend.position = "bottom",
    panel.grid.minor.x = element_blank(),
    axis.title = element_text(size = 20),
    axis.text.y = element_text(
      size = 15,
      angle = 0,
      hjust = 0.5,
      color = "black"
    ),
    axis.text.x = element_text(size = 15, color = "black"),
    plot.title = element_text(size = 25, hjust = 0.5),
    legend.key.size = unit(2, "line"),
    strip.text.x = element_text(size = 20, face = "bold.italic")
  ) +
  guides(fill = guide_legend(ncol = 4, byrow = TRUE))








#############################################
##Models
#############################################

##recession dummy
inkar_long.df$recession <- 0
inkar_long.df$recession[which(inkar_long.df$reportingyear == 2008 |
                                inkar_long.df$reportingyear == 2009)] <- 1
table(inkar_long.df$recession)

##migration crisis dummy
inkar_long.df$migration <- 0
inkar_long.df$migration[which(inkar_long.df$reportingyear == 2015)] <-
  1
table(inkar_long.df$migration)


##coef names for tables
names_long <- c(
  "Childcare coverage 0-2",
  "Share of full-time slots 0-2",
  "Childcare coverage 3-5",
  "Share of full-time slots 3-5",
  "Nr. of children 0-2",
  "Nr. of children 3-6",
  "Nr. of children 6-18",
  "% of females 18+",
  "% of females 25+",
  "% of females 65+",
  "Fertility rate",
  "% university entrance qual.",
  "% without formal qual.",
  "% students",
  "% female students",
  "Apprentice positions",
  "GDP",
  "Share of female employees (%)",
  "Unemployed females per 1000"
)

length(names_long)

#variable names for FE models
fe_x_vars_full <- c(
  "betreuungvonkindermunter3jahre",
  "ganztags.betreuungsquotekleink",
  "betreuungvonkinderm3bis5jahre",
  "ganztags.betreuungsquotevorsch",
  "einwohnerunter3jahren",
  "einwohnervon3bisunter6jahren",
  "einwohnervon6bisunter18jahren",
  "anteilweiblicheeinwohnervon18b",
  "anteilweiblicheeinwohnervon25b",
  "anteilweiblicheeinwohner65jahr",
  "fertilittsrate",
  "schulabgngermithochschulreife",
  "schulabgngerohneabschluss",
  "studierendeje100einwohner18bis",
  "anteilweiblichestudierende",
  "ausbildungspltze",
  "bruttoinlandsproduktjeeinwohne",
  "anteilweiblichesv.beschftigtea",
  "weiblichearbeitslose"
)

length(fe_x_vars_full)


fe_formula_full <-
  as.formula(paste(
    "beschftigtenquotefrauen ~ ",
    paste(fe_x_vars_full, collapse = "+")
  ))
fe_formula_full



#variable names for FEIS models
feis_x_vars_full <- c(
  "betreuungvonkindermunter3jahre",
  "ganztags.betreuungsquotekleink",
  "betreuungvonkinderm3bis5jahre",
  "ganztags.betreuungsquotevorsch",
  "einwohnerunter3jahren",
  "einwohnervon3bisunter6jahren",
  "einwohnervon6bisunter18jahren",
  "anteilweiblicheeinwohnervon18b",
  "anteilweiblicheeinwohnervon25b",
  "anteilweiblicheeinwohner65jahr",
  "fertilittsrate",
  "schulabgngermithochschulreife",
  "schulabgngerohneabschluss",
  "studierendeje100einwohner18bis",
  "anteilweiblichestudierende",
  "ausbildungspltze",
  "bruttoinlandsproduktjeeinwohne",
  "anteilweiblichesv.beschftigtea",
  "weiblichearbeitslose",
  "recession" ,
  "migration  |   reportingyear + I(reportingyear^2)"
)

length(feis_x_vars_full)

feis_formula_full <-
  as.formula(paste(
    "beschftigtenquotefrauen ~ ",
    paste(feis_x_vars_full , collapse = "+")
  ))
feis_formula_full



###Germany Model
summary(
  fe_Germany <- plm(
    fe_formula_full,
    index = c("kennziffer", "reportingyear"),
    data = inkar_long.df,
    model = "within",
    effect = "twoway"
  )
)

summary(
  feis_Germany <-
    feis(
      feis_formula_full ,
      id = "kennziffer",
      data = inkar_long.df,
      robust = TRUE,
      tol = 1e-32
    )
)



##############################
########FEIS FE models east west
##############################


##east west
summary(
  fe_West <- plm(
    fe_formula_full,
    index = c("kennziffer", "reportingyear"),
    data = inkar_long.df[inkar_long.df$ost == 0, ],
    model = "within",
    effect = "twoway"
  )
)


summary(
  fe_Ost <- plm(
    fe_formula_full,
    index = c("kennziffer", "reportingyear"),
    data = inkar_long.df[inkar_long.df$ost == 1, ],
    model = "within",
    effect = "twoway"
  )
)




summary(
  feis_West <-
    feis(
      feis_formula_full ,
      id = "kennziffer",
      data = inkar_long.df[inkar_long.df$ost == 0, ],
      robust = TRUE,
      tol = 1e-32
    )
)

summary(
  feis_Ost <-
    feis(
      feis_formula_full,
      id = "kennziffer",
      data = inkar_long.df[inkar_long.df$ost == 1, ],
      robust = TRUE,
      tol = 1e-32
    )
)


##############################
########FEIS area types
##############################


### FE
fe_Urban <- plm(
  fe_formula_full,
  index = c("kennziffer", "reportingyear"),
  data = inkar_long.df[inkar_long.df$kreistyp_fac == "Urban",],
  model = "within",
  effect = "twoway"
)


# robust SEs
fe_Urban$vcov <-
  vcovHC(fe_Urban, method = "arellano", cluster = "group")



feis_Urban <- feis(
  feis_formula_full ,
  id = "kennziffer",
  data = inkar_long.df[inkar_long.df$kreistyp_fac == "Urban",],
  robust = TRUE,
  tol = 1e-32
)


summary(feis_Urban)  ##


### FE
fe_Metro <- plm(
  fe_formula_full,
  index = c("kennziffer", "reportingyear"),
  data = inkar_long.df[inkar_long.df$kreistyp_fac == "Metro",],
  model = "within",
  effect = "twoway"
)


# robust SEs
fe_Metro$vcov <-
  vcovHC(fe_Metro, method = "arellano", cluster = "group")


feis_Metro <- feis(
  feis_formula_full ,
  id = "kennziffer",
  data = inkar_long.df[inkar_long.df$kreistyp_fac == "Metro" ,],
  robust = TRUE,
  tol = 1e-32
)


summary(feis_Metro)



### FE
fe_Rural <- plm(
  fe_formula_full,
  index = c("kennziffer", "reportingyear"),
  data = inkar_long.df[inkar_long.df$kreistyp_fac == "Rural",],
  model = "within",
  effect = "twoway"
)


# robust SEs
fe_Rural$vcov <-
  vcovHC(fe_Rural, method = "arellano", cluster = "group")

feis_Rural <- feis(
  feis_formula_full ,
  id = "kennziffer",
  data = inkar_long.df[inkar_long.df$kreistyp_fac == "Rural" ,],
  robust = TRUE,
  tol = 1e-32
)


summary(feis_Rural)  ##



### FE
fe_Agglo <- plm(
  fe_formula_full,
  index = c("kennziffer", "reportingyear"),
  data = inkar_long.df[inkar_long.df$kreistyp_fac == "Agglo",],
  model = "within",
  effect = "twoway"
)


# robust SEs
fe_Agglo$vcov <-
  vcovHC(fe_Agglo, method = "arellano", cluster = "group")


feis_Agglo <- feis(
  feis_formula_full ,
  id = "kennziffer",
  data = inkar_long.df[inkar_long.df$kreistyp_fac == "Agglo" ,],
  robust = TRUE,
  tol = 1e-32
)


summary(feis_Agglo)



#######################
#Appendix Table A2: FEIS Table export
#######################
FEIS <-
  texreg(
    list(
      feis_Germany,
      feis_Ost,
      feis_West,
      feis_Rural,
      feis_Agglo,
      feis_Urban,
      feis_Metro
    ),
    caption.above = TRUE,
    custom.model.names = c("Germany", "East", "West", "Rural", "Agglo", "Urban", "Metro"),
    custom.coef.names = c(names_long, "Recession 2008/2009", "Migration Crisis 2015"),
    label = "FEIS",
    ci.force = TRUE,
    table = FALSE,
    float.pos = "t"
  )
FEIS <- gsub("kennziffer", "id", FEIS)

FEIS


#######################
#Appendix Table A3: FE Table export
#######################
FE <-
  texreg(
    list(
      fe_Germany,
      fe_Ost,
      fe_West,
      fe_Rural,
      fe_Agglo,
      fe_Urban,
      fe_Metro
    ),
    caption.above = TRUE,
    custom.model.names = c("Germany", "East", "West", "Rural", "Agglo", "Urban", "Metro"),
    custom.coef.names = names_long,
    #custom.note = "%stars. Cluster robust standard errors, own calculations.",
    label = "FE",
    ci.force = TRUE,
    table = FALSE,
    float.pos = "t"
  )


FE




##############################
########FEIS TEST ROBUST
##############################

##feistests
feistestfun_var_02 <- function (x, var) {
  AA <- bsfeistest(
    x,
    robust = TRUE,
    type = "bs1",
    rep = 500,
    terms = c("betreuungvonkindermunter3jahre")
  )
  chi2 <- AA$wald_feis$result$chi2
  print(chi2)
}

feistestfun_var_02_full <- function (x, var) {
  AA <- bsfeistest(
    x,
    robust = TRUE,
    type = "bs1",
    rep = 500,
    terms = c("ganztags.betreuungsquotekleink")
  )
  chi2 <- AA$wald_feis$result$chi2
  print(chi2)
}

feistestfun_var_35 <- function (x, var) {
  AA <- bsfeistest(
    x,
    robust = TRUE,
    type = "bs1",
    rep = 500,
    terms = c("betreuungvonkinderm3bis5jahre")
  )
  chi2 <- AA$wald_feis$result$chi2
  print(chi2)
}

feistestfun_var_35_full <- function (x, var) {
  AA <- bsfeistest(
    x,
    robust = TRUE,
    type = "bs1",
    rep = 500,
    terms = c("ganztags.betreuungsquotevorsch")
  )
  chi2 <- AA$wald_feis$result$chi2
  print(chi2)
}

mods_feis <-
  list(feis_Germany,
       feis_Ost,
       feis_West,
       feis_Rural,
       feis_Agglo,
       feis_Urban,
       feis_Metro)

########################
#Artificial Regression Tests and export (multicore for performence)
########################
FE_FEIS_02 <- mclapply(mods_feis, function(x)
  feistestfun_var_02(x))
FE_FEIS_02_full <-
  mclapply(mods_feis, function(x)
    feistestfun_var_02_full(x))
FE_FEIS_35 <- mclapply(mods_feis, function(x)
  feistestfun_var_35(x))
FE_FEIS_35_full <-
  mclapply(mods_feis, function(x)
    feistestfun_var_35_full(x))


Temp1 <-
  data.frame(
    t(sapply(FE_FEIS_02, c)),
    c("Germany", "East", "West", "Rural", "Agglo", "Urban", "Metro"),
    "Childcare coverage 0 to 2"
  )
Temp2 <-
  data.frame(
    t(sapply(FE_FEIS_02_full, c)),
    c("Germany", "East", "West", "Rural", "Agglo", "Urban", "Metro"),
    "Share of full-time slots 0 to 2"
  )

colnames(Temp1) <-
  c("$\\chi^2$", "df", "$P(>\\chi^2$)", "Area", "Child Care type")
colnames(Temp2) <-
  c("$\\chi^2$", "df", "$P(>\\chi^2$)", "Area", "Child Care type")


########################
###Table 1
########################

Table1 <- rbind(Temp1, Temp2)
Table1


Temp3 <-
  data.frame(
    t(sapply(FE_FEIS_35, c)),
    c("Germany", "East", "West", "Rural", "Agglo", "Urban", "Metro"),
    "Childcare coverage 3 to 5"
  )
Temp4 <-
  data.frame(
    t(sapply(FE_FEIS_35_full, c)),
    c("Germany", "East", "West", "Rural", "Agglo", "Urban", "Metro"),
    "Share of full-time slots 3 to 5"
  )

colnames(Temp3) <-
  c("$\\chi^2$", "df", "$P(>\\chi^2$)", "Area", "Child Care Type")
colnames(Temp4) <-
  c("$\\chi^2$", "df", "$P(>\\chi^2$)", "Area", "Child Care Type")


########################
###Table 2
########################

Table2 <- rbind(Temp3, Temp4)
Table2


########################
###Appendix Figure A5
########################

setwd(paste0(wd))
getwd()
library(sf)
library(Rcpp)
#county layer
ot <- st_read(dsn = "vg2500_01-01.utm32s.shape/vg2500",
              layer = "vg2500_krs")
ot$RS <- as.numeric(as.character(ot$ARS))



#federal state layer
otbula <- st_read(dsn = "./vg2500_01-01.utm32s.shape/vg2500",
                  layer = "vg2500_lan")

length(unique(inkar_long.df$kennziffer))
length(unique(ot$ARS))

#prepare kennziffer with leading zero to merge to map data
head(inkar_long.df$kennziffer)
inkar_long.df$kennziffer <- as.character(inkar_long.df$kennziffer)
inkar_long.df$kennziffer <-
  ifelse(
    nchar(inkar_long.df$kennziffer) < 5 ,
    paste0("0", inkar_long.df$kennziffer),
    inkar_long.df$kennziffer
  )
head(inkar_long.df$kennziffer)



ts <- merge(
  x = ot,
  y = inkar_long.df,
  by.x = "ARS",
  by.y = "kennziffer",
  all.x = T,
  all.y = F
)

#re-order kreistyp for legend
ts$kreistyp_fac <- factor(ts$kreistyp_fac)
levels(ts$kreistyp_fac)
ts$kreistyp_fac <- fct_rev(ts$kreistyp_fac)

#colors
cbPalette <- c(viridis(
  4,
  begin = 0.15,
  end = 0.95,
  direction = -1
))



tm_shape(ts) +  #print
  tm_fill(
    col = "kreistyp_fac",
    style = "cat",
    # Variable
    title = "Area Types",
    palette = c(cbPalette),
    legend.hist = FALSE
  ) +
  tm_borders(col = "white") +
  tm_layout(
    legend.outside = T,
    legend.outside.position = "right",
    legend.text.size = 2,
    legend.title.size = 3,
    frame = FALSE
  ) +
  tm_shape(otbula) +
  tm_borders(col = "grey30", lwd = 1.5)





##################
#main result graphics
#################
##basic table
B <-
  as.data.frame(
    rbind(
      cbind(
        summary(fe_Germany)$coef[1:4, ],
        rep("FE", 4),
        rep("Germany", 4) ,
        rep("1 FE Germany", 4)
      ),
      cbind(
        summary(feis_Germany)$coef[1:4, ],
        rep("FEIS", 4),
        rep("Germany", 4),
        rep("1 FEIS Germany", 4)
      ),
      cbind(
        summary(fe_Ost)$coef[1:4, ],
        rep("FE", 4),
        rep("East", 4),
        rep("2 FE East", 4)
      ),
      cbind(
        summary(feis_Ost)$coef[1:4, ],
        rep("FEIS", 4),
        rep("East", 4),
        rep("2 FEIS East", 4)
      ),
      cbind(
        summary(fe_West)$coef[1:4, ],
        rep("FE", 4),
        rep("West", 4),
        rep("3 FE West", 4)
      ),
      cbind(
        summary(feis_West)$coef[1:4, ],
        rep("FEIS", 4),
        rep("West", 4),
        rep("3 FEIS West", 4)
      ),
      cbind(
        summary(fe_Metro)$coef[1:4, ],
        rep("FE", 4),
        rep("Metro", 4),
        rep("2 FE Metro", 4)
      ),
      cbind(
        summary(feis_Metro)$coef[1:4, ],
        rep("FEIS", 4),
        rep("Metro", 4),
        rep("2 FEIS Metro", 4)
      ),
      cbind(
        summary(fe_Urban)$coef[1:4, ],
        rep("FE", 4),
        rep("Urban", 4),
        rep("3 FE Urban", 4)
      ),
      cbind(
        summary(feis_Urban)$coef[1:4, ],
        rep("FEIS", 4),
        rep("Urban", 4),
        rep("3 FEIS Urban", 4)
      ),
      cbind(
        summary(fe_Agglo)$coef[1:4, ],
        rep("FE", 4),
        rep("Agglo", 4),
        rep("4 FE Agglo", 4)
      ),
      cbind(
        summary(feis_Agglo)$coef[1:4, ],
        rep("FEIS", 4),
        rep("Agglo", 4),
        rep("4 FEIS Agglo", 4)
      ),
      cbind(
        summary(fe_Rural)$coef[1:4, ],
        rep("FE", 4),
        rep("Rural", 4),
        rep("5 FE Rural", 4)
      ),
      cbind(
        summary(feis_Rural)$coef[1:4, ],
        rep("FEIS", 4),
        rep("Rural", 4),
        rep("5 FEIS Rural", 4)
      )
    )
  )
B

B2 <-
  cbind(B, rep(
    c(
      "Childcare coverage 0-2",
      "Share of full-time slots 0-2",
      "Childcare coverage 3-5",
      "Share of full-time slots 3-5"
    ),
    dim(B)[1] / 4
  ))
colnames(B2)
B2


colnames(B2)[2] <- "SE"
colnames(B2)[5] <- "Model"
colnames(B2)[6] <- "Area"
colnames(B2)[7] <- "Variable"
colnames(B2)[8] <- "Var"

B2$Estimate <- as.double(as.character(B2$Estimate))
B2$SE <- as.double(as.character(B2$SE))

temp <- B2

colnames(temp)
head(temp)

temp$Var <- as.factor(temp$Var)
levels(temp$Var)
temp$Var <- ordered(
  temp$Var,
  levels = c(
    "Childcare coverage 0-2",
    "Share of full-time slots 0-2",
    "Childcare coverage 3-5",
    "Share of full-time slots 3-5"
  )
)



temp$Variable_new <- as.factor(paste0(temp$Area, " ",  temp$Model))
temp$Variable_new
levels(temp$Variable_new)
class(temp$Variable_new)


temp$order[grepl("Germany", temp$Variable)] <- 1
temp$order[grepl("East", temp$Variable)] <- 2
temp$order[grepl("West", temp$Variable)] <- 3
temp$order[grepl("Metro", temp$Variable)] <- 7
temp$order[grepl("Urban", temp$Variable)] <- 6
temp$order[grepl("Agglo", temp$Variable)] <- 5
temp$order[grepl("Rural", temp$Variable)] <- 4
temp$order <- as.numeric(temp$order)
temp
temp$Area <- fct_reorder(temp$Area, temp$order, min)
levels(temp$Area)

temp$Area <- fct_rev(temp$Area)
temp$Model <- fct_rev(temp$Model)

colnames(temp)[4] <- "pval"
colnames(temp)[4]

temp$pval <- as.numeric(temp$pval)
temp$sig[abs(temp$pval) < 0.05] <-  "t<0.05  *  "
temp$sig[abs(temp$pval) < 0.01] <-  "t<0.01  ** "
temp$sig[abs(temp$pval) < 0.001] <- "t<0.001 ***"

temp$alph <- 0
temp$alph[!is.na(temp$sig)] <- 1

temp



library(viridisLite)
cbPalette <-
  c(
    "black",
    inferno(
      2,
      begin = 0.5,
      end = 0.8,
      direction = -1
    ),
    #"white",
    viridis(
      4,
      begin = 0.3,
      end = 0.9,
      direction = -1
    )
  )


Figure1 <-
  ggplot(temp[grepl("0-2", temp$Var), ], aes(Area, Estimate)) +
  geom_point(
    aes(
      alpha = alph,
      shape = Model,
      color = Area,
      fill = Area
    ),
    na.rm = TRUE,
    size = 5,
    position = position_dodge(width = .7)
  ) +
  geom_point(
    aes(shape = Model,
        color = Area),
    na.rm = TRUE,
    size = 5,
    stroke = 1.5,
    position = position_dodge(width = .7),
    show.legend = FALSE
  ) +
  geom_errorbar(
    aes(
      ymin = Estimate + SE * -1.96,
      ymax = Estimate + SE * 1.96,
      #alpha = alph,
      color = Area,
      lty = Model
    ),
    position = position_dodge(width = .7),
    width = 0,
    size = 1
  ) +
  scale_alpha(range = c(0.3, 1), guide = "none") +
  scale_color_manual(values = rev(cbPalette)) +
  scale_fill_manual(values = rev(cbPalette), guide = "none") +
  scale_shape_manual(values = c(24, 21)) +
  scale_linetype_manual(values = c(1, 1), guide = "none") +
  ylab("Coefficients") +
  xlab("") +
  theme_light(base_size = 16) +
  ggforce::facet_col(vars(Var), scales = 'free', space = 'free') +
  coord_flip() +
  geom_hline(yintercept = 0,
             lty = 1,
             col = "grey40") +
  geom_vline(xintercept = 4.5,
             linetype = 2,
             col = "grey40") +
  geom_vline(xintercept = 6.5,
             linetype = 2,
             col = "grey40") +
  guides(
    shape = guide_legend(
      reverse = TRUE,
      override.aes = list(size = 5, stroke = 1.5),
      order = 2
    ),
    color = guide_legend(
      reverse = TRUE,
      override.aes = list(size = 5),
      order = 1
    ),
    type =  guide_legend(
      reverse = TRUE,
      override.aes = list(size = 5),
      order = 3
    )
  ) +
  theme(
    legend.title = element_blank(),
    legend.text = element_text(size = 20),
    panel.grid.major.x = element_blank(),
    panel.grid.minor.x = element_blank(),
    axis.title = element_text(size = 20),
    axis.text.y = element_text(color = "black", size = 16),
    axis.text.x = element_text(color = "black", size = 16),
    strip.text.x = element_text(size = 15, face = "bold.italic")
  )

Figure1



Figure2 <-
  ggplot(temp[grepl("3-5", temp$Var), ], aes(Area, Estimate)) +
  geom_point(
    aes(
      alpha = alph,
      shape = Model,
      color = Area,
      fill = Area
    ),
    na.rm = TRUE,
    size = 5,
    position = position_dodge(width = .7)
  ) +
  geom_point(
    aes(shape = Model,
        color = Area),
    na.rm = TRUE,
    size = 5,
    stroke = 1.5,
    position = position_dodge(width = .7),
    show.legend = FALSE
  ) +
  geom_errorbar(
    aes(
      ymin = Estimate + SE * -1.96,
      ymax = Estimate + SE * 1.96,
      #alpha = alph,
      color = Area,
      lty = Model
    ),
    position = position_dodge(width = .7),
    width = 0,
    size = 1
  ) +
  scale_alpha(range = c(0.3, 1), guide = "none") +
  scale_color_manual(values = rev(cbPalette)) +
  scale_fill_manual(values = rev(cbPalette), guide = "none") +
  scale_shape_manual(values = c(24, 21)) +
  scale_linetype_manual(values = c(1, 1), guide = "none") +
  ylab("Coefficients") +
  xlab("") +
  theme_light(base_size = 16) +
  ggforce::facet_col(vars(Var), scales = 'free', space = 'free') +
  coord_flip() +
  geom_hline(yintercept = 0,
             lty = 1,
             col = "grey40") +
  geom_vline(xintercept = 4.5,
             linetype = 2,
             col = "grey40") +
  geom_vline(xintercept = 6.5,
             linetype = 2,
             col = "grey40") +
  guides(
    shape = guide_legend(
      reverse = TRUE,
      override.aes = list(size = 5, stroke = 1.5),
      order = 2
    ),
    color = guide_legend(
      reverse = TRUE,
      override.aes = list(size = 5),
      order = 1
    ),
    type =  guide_legend(
      reverse = TRUE,
      override.aes = list(size = 5),
      order = 3
    )
  ) +
  theme(
    legend.title = element_blank(),
    legend.text = element_text(size = 20),
    # legend.position = "bottom",
    panel.grid.major.x = element_blank(),
    panel.grid.minor.x = element_blank(),
    axis.title = element_text(size = 20),
    axis.text.y = element_text(color = "black", size = 16),
    axis.text.x = element_text(color = "black", size = 16),
    strip.text.x = element_text(size = 15, face = "bold.italic")
  )



Figure2
